@@ -315,3 +315,20 @@ class Dataset(APIResource):
             'pipeline': [Pipeline(e) for e in response['pipeline']],
         }
         return WhatifyResponse(data=new_data)
+
+    @classmethod
+    def get_metadata(cls, id: int, api_key: str = None) -> WhatifyResponse:
+        """
+        Gets metadata for a specific Dataset.
+
+        Args:
+            id (int): Dataset ID.
+            api_key (Optional[str]): Explicit `api_key`, not required, if `fireflyai.authenticate()` was run prior.
+
+        Returns:
+            WhatifyResponse: Contains mapping of metadata.
+        """
+        requestor = APIRequestor()
+        url = '{prefix}/{id}/meta'.format(prefix=cls._CLASS_PREFIX, id=id)
+        response = requestor.get(url, api_key=api_key)
+        return response
