@@ -274,9 +274,17 @@ class MyWhatify:
         return sens[alg]
 
     # @classmethod
-    # def func_base(cls, func, file_id):
-    #     for id in file_id:
-    #         func(file_id)
+    # def func_base(cls, func, list_ids):
+    #     for id in list_ids:
+    #         func(id)
+    #
+    # @classmethod
+    # def delete_data_source_by_name(cls, data_name):
+    #     logging.info('deleting data Source with data_name: ' + str(data_name))
+    #     data_id_list = my_toolkit.Datasource.list(search_term=data_name)
+    #     data_id_list = [d['id'] for d in data_id_list['hits']]
+    #     cls.func_base(func=my_toolkit.Datasource.delete, file_id=data_id_list)
+    #     # my_toolkit.Datasource.delete(data_id)
 
     @classmethod
     def delete_data_source(cls, data_id):
@@ -454,6 +462,17 @@ class MyWhatify:
             error_message = predict_results['error_message']
         return error_message
 
+    @classmethod
+    def get_metadata_datasource(cls, data_id):
+        with allure.step('getting metadata for data id: ' + str(data_id)):
+            metadata_results = my_toolkit.Datasource.get_metadata(data_id)
+        return metadata_results
+
+    @classmethod
+    def get_metadata_dataset(cls, data_id):
+        with allure.step('getting metadata for data id: ' + str(data_id)):
+            metadata_results = my_toolkit.Dataset.get_metadata(data_id)
+        return metadata_results
     #############################
     ###        Wisdoms        ###
     #############################
